NotchCardClipper class final

Inheritance

Constructors

NotchCardClipper({required NotchedShape shape, TextDirection? textDirection, ShapeBorder? borderShap, required GlobalKey<State<StatefulWidget>> hostKey, required GlobalKey<State<StatefulWidget>> guestKey, required double notchMargin})
const

Properties

borderShap ShapeBorder?
final
guestKey GlobalKey<State<StatefulWidget>>
final
hashCode int
The hash code for this object.
no setterinherited
hostKey GlobalKey<State<StatefulWidget>>
final
notchMargin double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shape NotchedShape
final
textDirection TextDirection?
final

Methods

addListener(VoidCallback listener) → void
Register a closure to be notified when it is time to reclip.
inherited
boxToRect(RenderBox? box, {RenderObject? ancestor}) Rect?
getApproximateClipRect(Size size) Rect
Returns an approximation of the clip returned by getClip, as an axis-aligned Rect. This is used by the semantics layer to determine whether widgets should be excluded.
inherited
getClip(Size size) Path
Returns a description of the clip given that the render object being clipped is of the given size.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies when it is time to reclip.
inherited
shouldReclip(covariant NotchCardClipper oldClipper) bool
Called whenever a new instance of the custom clipper delegate class is provided to the clip object, or any time that a new clip object is created with a new instance of the custom clipper delegate class (which amounts to the same thing, because the latter is implemented in terms of the former).
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited