NotchCardPosition enum

Inheritance
Available extensions

Values

top → const NotchCardPosition
bottom → const NotchCardPosition
left → const NotchCardPosition

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isInverted bool
Returns true if the direction is right or bottom.
no setter
isSide bool
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<NotchCardPosition>
A constant List of the values in this enum, in order of their declaration.